dragWidth property

double? dragWidth
final

The width of the area within which a horizontal swipe will open the drawer, defaults to DrawerScaffold.drawerEdgeDragWidth or DrawerScaffold.endDrawerEdgeDragWidth. If the corresponding value is null, it will fallback to 20.0 with MediaQuery horizontal padding.

Implementation

final double? dragWidth;